@@ -64,7 +64,7 @@ Application::Application(const QString& fileName, QApt::Backend* backend)
     m_isTechnical = getField("NoDisplay").toLower() == "true"
                     || !hasField("Exec")
                     || getField("NotShowIn", QByteArray()).contains(currentDesktop)
-                    || getField("OnlyShowIn", currentDesktop).contains(currentDesktop);
+                    || !getField("OnlyShowIn", currentDesktop).contains(currentDesktop);
     m_packageName = getField("X-AppInstall-Package");
 }
 
@@ -157,9 +157,9 @@ QString Application::icon() const
     return getField("Icon", "applications-other");
 }
 
-QString Application::mimetypes() const
+QStringList Application::mimetypes() const
 {
-    return getField("MimeType");
+    return QString(getField("MimeType")).split(';');
 }
 
 QString Application::menuPath()
@@ -252,14 +252,14 @@ QVector<QPair<QString, QString> > Application::locateApplication(const QString &
     return ret;
 }
 
-QString Application::categories()
+QStringList Application::categories()
 {
-    QString categories = getField("Categories");
+    QStringList categories = QString(getField("Categories")).split(',', QString::SkipEmptyParts);
 
     if (categories.isEmpty()) {
         // extras.ubuntu.com packages can have this field
         if (m_isExtrasApp)
-            categories = package()->controlField(QLatin1String("Category"));
+            categories += package()->controlField(QLatin1String("Category"));
     }
     return categories;
 }
@@ -388,7 +388,7 @@ bool Application::hasField(const char* field) const
     return m_data && m_data->group("Desktop Entry").hasKey(field);
 }
 
-QUrl Application::homepage() const
+QUrl Application::homepage()
 {
     if(!m_package) return QString();
     return m_package->homepage();
@@ -400,7 +400,7 @@ QString Application::origin() const
     return m_package->origin();
 }
 
-QString Application::longDescription() const
+QString Application::longDescription()
 {
     if(!m_package) return QString();
     return m_package->longDescription();
@@ -505,7 +505,6 @@ void Application::fetchScreenshots()
         return;
     
     QString dest = KStandardDirs::locate("tmp", "screenshots."+m_packageName);
-    //TODO: Make async
     const KUrl packageUrl(MuonDataSources::screenshotsSource(), "/json/package/"+m_packageName);
     KIO::StoredTransferJob* job = KIO::storedGet(packageUrl, KIO::NoReload, KIO::HideProgressInfo);
     connect(job, SIGNAL(finished(KJob*)), SLOT(downloadingScreenshotsFinished(KJob*)));
